# Generated by roxygen2: do not edit by hand

S3method(plot,backtest_result)
S3method(plot,param_grid_result)
S3method(plot,performance_analysis)
S3method(plot,wf_optimization_result)
S3method(print,backtest_result)
S3method(print,param_grid_result)
S3method(print,performance_analysis)
S3method(print,wf_optimization_result)
S3method(summary,backtest_result)
export(align_to_timeframe)
export(analyze_by_period)
export(analyze_drawdowns)
export(analyze_performance)
export(analyze_vs_benchmark)
export(apply_regime)
export(as_selection)
export(backtest_metrics)
export(bucket_returns)
export(calc_cci)
export(calc_distance)
export(calc_market_breadth)
export(calc_momentum)
export(calc_moving_average)
export(calc_relative_strength_rank)
export(calc_rolling_correlation)
export(calc_rolling_volatility)
export(calc_rsi)
export(calc_sector_breadth)
export(calc_sector_relative_indicators)
export(calc_stochastic_d)
export(calc_stochrsi)
export(calculate_daily_values)
export(calculate_drawdown_series)
export(cap_exposure)
export(cap_turnover)
export(carry_forward_weights)
export(combine_filters)
export(combine_scores)
export(combine_weights)
export(convert_to_nweeks)
export(coverage_by_date)
export(create_regime_buckets)
export(csv_adapter)
export(cv_tune_seq)
export(demo_sector_map)
export(download_sp500_sectors)
export(ensure_dt_copy)
export(evaluate_scores)
export(filter_above)
export(filter_below)
export(filter_between)
export(filter_by_percentile)
export(filter_rank)
export(filter_threshold)
export(filter_top_n)
export(filter_top_n_where)
export(get_data_frequency)
export(ic_series)
export(invert_signal)
export(join_panels)
export(limit_positions)
export(list_examples)
export(load_mixed_symbols)
export(make_labels)
export(manual_adapter)
export(membership_stability)
export(metric_sharpe)
export(ml_add_interactions)
export(ml_backtest)
export(ml_backtest_multi)
export(ml_backtest_seq)
export(ml_ic_series_on_scores)
export(ml_make_ensemble)
export(ml_make_model)
export(ml_make_seq_model)
export(ml_panel_op)
export(ml_panel_reduce)
export(ml_plot_ic_roll)
export(ml_prepare_features)
export(panel_lag)
export(panel_returns_simple)
export(perf_metrics)
export(portfolio_returns)
export(pt_collect_results)
export(rank_within_sector)
export(rebalance_calendar)
export(roll_fit_predict)
export(roll_fit_predict_seq)
export(roll_ic_stats)
export(run_backtest)
export(run_example)
export(run_param_grid)
export(run_walk_forward)
export(safe_divide)
export(scores_oos_only)
export(select_top_k_scores)
export(select_top_k_scores_by_group)
export(sql_adapter)
export(sql_adapter_adjusted)
export(switch_weights)
export(transform_scores)
export(tune_ml_backtest)
export(turnover_by_date)
export(update_vix_in_db)
export(validate_data_format)
export(validate_group_map)
export(validate_no_leakage)
export(vol_target)
export(weight_by_hrp)
export(weight_by_rank)
export(weight_by_regime)
export(weight_by_risk_parity)
export(weight_by_signal)
export(weight_by_volatility)
export(weight_equally)
export(weight_from_scores)
export(wf_report)
export(wf_stitch)
export(wf_sweep_tabular)
export(yahoo_adapter)
importFrom(TTR,CCI)
importFrom(TTR,RSI)
importFrom(TTR,runMax)
importFrom(TTR,runMin)
importFrom(data.table,":=")
importFrom(data.table,.SD)
importFrom(data.table,as.data.table)
importFrom(data.table,copy)
importFrom(data.table,data.table)
importFrom(data.table,dcast)
importFrom(data.table,fifelse)
importFrom(data.table,fread)
importFrom(data.table,frollapply)
importFrom(data.table,frollmean)
importFrom(data.table,is.data.table)
importFrom(data.table,melt)
importFrom(data.table,rbindlist)
importFrom(data.table,setDT)
importFrom(data.table,setkey)
importFrom(data.table,setnames)
importFrom(data.table,setorder)
importFrom(data.table,shift)
importFrom(grDevices,hcl.colors)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,box)
importFrom(graphics,grid)
importFrom(graphics,hist)
importFrom(graphics,image)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,persp)
importFrom(graphics,plot)
importFrom(graphics,plot.new)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(stats,IQR)
importFrom(stats,acf)
importFrom(stats,aggregate)
importFrom(stats,approx)
importFrom(stats,as.dist)
importFrom(stats,as.formula)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,cov2cor)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,predict)
importFrom(stats,qqline)
importFrom(stats,qqnorm)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(utils,head)
importFrom(utils,tail)
importFrom(utils,write.csv)
importFrom(zoo,index)
